<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Название программы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Выйти из приложения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Дальше</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation>Просмотр журнала</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="505"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Select ISO</source>
        <translation>Выбор ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Выбор целевого USB накопителя&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>Выбор файла ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Расширенные опции</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Создать ФС ext4 если уже существует</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Сохранить имеющуюся бут директорию при обновлении live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Использовать gpt разделы вместо msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>Партиционирование GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Обновить (только для существующего live-usb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Не заменять файлы syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Оставить файлы syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Игнорировать проверку USB/извлекаемое</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Временно отключить автомонтирование</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Установить флаг накопителя pmbr_boot (не будет загружаться через UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Не использовать fuseiso для монтирования файлов iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Размер раздела ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Степень детализации (от меньшего к большему):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation>Создать отдельный раздел данных (проценты)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>Обновить список накопителей</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Show advanced options</source>
        <translation>Показать расширенные опции</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Полнофункциональный режим - записывае&amp;мый LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Режим только на чтение, невозможно запомнить сеанс</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Режим образа - LiveUSB (dd) тол&amp;ько для чтения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Для дистрибутивов отличных от antiX/MX используйте Режим образа (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>Процент использования USB-накопителя:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>Метка раздела ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Не выполнять команды, влияющие на usb накопитель</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>Пробный прогон (без изменений системы)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Клонировать с подмонтированного live-usb или iso-файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>Клонировать существующую live систему</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Настроить загрузку с зашифрованного раздела, запросит пароль при первой загрузке</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>Зашифровать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>Клонировать работающую live систему</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Confirmation</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Целевое устройство %1 превышает %2 GB. Вы хотите продолжить?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Failure</source>
        <translation>Сбой</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Источник и место назначения на одном устройстве, выберите еще раз.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Success</source>
        <translation>Успешно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>LiveUSB creation successful!</source>
        <translation>Создание LiveUSB завершено успешно!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Произошла ошибка при создании LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Please select a USB device to write to</source>
        <translation>Выберите USB накопитель для записи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Данные действия уничтожат данные на
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Do you wish to continue?</source>
        <translation>Вы хотите продолжить?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Приложение для создания live-usb из файла ISO, другого live-usb, live-cd/dvd или запущенной live системы.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Авторское право (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Выберите файл ISO для записи на USB накопитель</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>Файлы вида ISO (*.iso);;Файлы всех типов (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Select Source Directory</source>
        <translation>Выберите директорию источника</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Не найден файл %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Hide advanced options</source>
        <translation>Скрыть расширенные опции</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Select Source</source>
        <translation>Выберите источник</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Select ISO file</source>
        <translation>Выберите файл ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>clone</source>
        <translation>клонировать</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Could not find a log file at: </source>
        <translation>Не удалось найти файл журнала в:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Приложение для создания live-usb из файла ISO, другого live-usb, live-cd/dvd или запущенной live системы.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>filename</source>
        <translation>имя файла</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Name of .iso file to open</source>
        <translation>Имя файла .iso для открытия</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>[filename]</source>
        <translation>[имя файла]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>version:</source>
        <translation>версия:</translation>
    </message>
</context>
</TS>
